extract_model_data: Extract model data

View source: R/extract_model_data.R

extract_model_dataR Documentation

Extract model data

Description

This is mostly just a wrapper for model.frame.

Usage

extract_model_data(model)

Arguments

model

The mixed model.

Value

A tibble of the data used in the model.

Note

For whatever reason, nlme class objects do not save the model data, so this will throw an error stating as much. lme objects do save the data so are fine.

See Also

model.frame

Other extract: extract_cor_structure(), extract_fixed_effects(), extract_het_var(), extract_random_coefs(), extract_random_effects(), extract_vc()

Examples

library(lme4)
library(mixedup)

lmer_1 <- lmer(Reaction ~ Days + (1 | Subject), data = sleepstudy)
extract_model_data(lmer_1)



m-clark/mixedup documentation built on Oct. 15, 2022, 8:55 a.m.