View source: R/extract_model_data.R
| extract_model_data | R Documentation |
This is mostly just a wrapper for model.frame.
extract_model_data(model)
model |
The mixed model. |
A tibble of the data used in the model.
For whatever reason, nlme class objects do not save the model data,
so this will throw an error stating as much. lme objects do save the data
so are fine.
model.frame
Other extract:
extract_cor_structure(),
extract_fixed_effects(),
extract_het_var(),
extract_random_coefs(),
extract_random_effects(),
extract_vc()
library(lme4) library(mixedup) lmer_1 <- lmer(Reaction ~ Days + (1 | Subject), data = sleepstudy) extract_model_data(lmer_1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.